summaryrefslogtreecommitdiff
path: root/src/com/android/bitmap/RequestKey.java
diff options
context:
space:
mode:
authorMark Wei <markwei@google.com>2013-10-21 16:11:15 -0700
committerMark Wei <markwei@google.com>2013-10-21 19:50:52 -0700
commitcea0c012d538f11b3ee97d4b7e78f4c1ea73d5be (patch)
tree9506342cb46c574f3913c762f6e11d08b532acfd /src/com/android/bitmap/RequestKey.java
parent7a0df68fac718a68ed44d5c667ebaee38e334f63 (diff)
downloadbitmap-cea0c012d538f11b3ee97d4b7e78f4c1ea73d5be.tar.gz
Modifications to bitmap library to make integrating into BigTop simpler.
RequestKey returns ParcelFileDescriptor instead of AssetFileDescriptor to make it easier to read files off of internal cache. Do not assume we want a top-1/3 crop. Provide vertical center in DecodeTask constructor. Move DecodeTask params into DecodeOptions to avoid param bloat. Add option to not limit bitmap density in BasicBitmapDrawable. Name AsyncTask threads in pool. Link DEBUG flags. Change-Id: I9416ac647c0c4935ee488b7db43cccd9de565c54
Diffstat (limited to 'src/com/android/bitmap/RequestKey.java')
-rw-r--r--src/com/android/bitmap/RequestKey.java9
1 files changed, 4 insertions, 5 deletions
diff --git a/src/com/android/bitmap/RequestKey.java b/src/com/android/bitmap/RequestKey.java
index 108b255..0e92164 100644
--- a/src/com/android/bitmap/RequestKey.java
+++ b/src/com/android/bitmap/RequestKey.java
@@ -16,8 +16,7 @@
package com.android.bitmap;
-import android.content.res.AssetFileDescriptor;
-
+import android.os.ParcelFileDescriptor;
import java.io.IOException;
import java.io.InputStream;
@@ -36,10 +35,10 @@ import java.io.InputStream;
public interface RequestKey {
/**
* Create an {@link AssetFileDescriptor} for a local file stored on the device. This method will
* be called first; if it returns null, {@link #createInputStream()} will be called.
*/
- public AssetFileDescriptor createFd() throws IOException;
+ public ParcelFileDescriptor createFd() throws IOException;
/**
* Create an {@link InputStream} for a file. This method will be called if {@link #createFd()}
@@ -36,10 +35,10 @@ import java.io.InputStream;
public interface RequestKey {
/**
- * Create an {@link AssetFileDescriptor} for a local file stored on the device. This method will
- * be called first; if it returns null, {@link #createInputStream()} will be called.
+ * Create an {@link ParcelFileDescriptor} for a local file stored on the device. This method
+ * will be called first; if it returns null, {@link #createInputStream()} will be called.
*/